@@ -41,10 +41,7 @@ bdm_create_graph <- function(data_model,
 }
 
 bdm_render_graph <- function(graph, width = NULL, height = NULL, top_level_fun = NULL) {
-  check_suggested("DiagrammeR",
-    use = TRUE,
-    top_level_fun = top_level_fun
-  )
+  check_suggested("DiagrammeR", top_level_fun)
 
   if (is.null(graph$dot_code)) {
     graph$dot_code <- dot_graph(graph)
@@ -371,7 +368,7 @@ dot_html_label <- function(x, title, palette_id = "default", col_attr = c("colum
     if (col_name == "column" && row_values[["key"]] == 1 && row_values[["kind"]] == "PK") {
       value <- sprintf("<U>%s</U>", value)
     } else if (col_name == "column" && row_values[["key"]] == 1 && row_values[["kind"]] != "PK") {
-      value <- sprintf('<I>%s</I>', value)
+      value <- sprintf("<I>%s</I>", value)
     }
     if (!is.null(value) && is.na(value)) {
       value <- ""
