@@ -23,7 +23,7 @@ test_that("validator speaks up when something's wrong", {
     dm_for_filter() %>%
       dm_get_def() %>%
       mutate(col_tracker_zoom = list(1)) %>%
-      new_dm3() %>%
+      dm_from_def() %>%
       dm_validate(),
     "dm_invalid"
   )
@@ -34,7 +34,7 @@ test_that("validator speaks up when something's wrong", {
       dm_zoom_to(tf_1) %>%
       dm_get_def() %>%
       mutate(zoom = list(NULL)) %>%
-      new_dm3(zoomed = TRUE) %>%
+      dm_from_def(zoomed = TRUE) %>%
       dm_validate(),
     "dm_invalid"
   )
@@ -45,7 +45,7 @@ test_that("validator speaks up when something's wrong", {
       dm_zoom_to(tf_1) %>%
       dm_get_def() %>%
       mutate(col_tracker_zoom = list(NULL)) %>%
-      new_dm3(zoomed = TRUE) %>%
+      dm_from_def(zoomed = TRUE) %>%
       dm_validate(),
     "dm_invalid"
   )
@@ -55,7 +55,7 @@ test_that("validator speaks up when something's wrong", {
     dm_for_filter() %>%
       dm_get_def() %>%
       mutate(table = "") %>%
-      new_dm3() %>%
+      dm_from_def() %>%
       dm_validate(),
     "dm_invalid"
   )
@@ -65,7 +65,7 @@ test_that("validator speaks up when something's wrong", {
     dm_for_filter() %>%
       dm_get_def() %>%
       mutate(zoom = list(1)) %>%
-      new_dm3() %>%
+      dm_from_def() %>%
       dm_validate(),
     "dm_invalid"
   )
@@ -76,7 +76,7 @@ test_that("validator speaks up when something's wrong", {
       dm_zoom_to(tf_1) %>%
       dm_get_def() %>%
       mutate(zoom = if_else(table == "tf_1", list(1), list(NULL))) %>%
-      new_dm3(zoomed = TRUE) %>%
+      dm_from_def(zoomed = TRUE) %>%
       dm_validate(),
     "dm_invalid"
   )
@@ -87,7 +87,7 @@ test_that("validator speaks up when something's wrong", {
       dm_zoom_to(tf_1) %>%
       dm_get_def() %>%
       mutate(zoom = list(tf_1)) %>%
-      new_dm3(zoomed = TRUE) %>%
+      dm_from_def(zoomed = TRUE) %>%
       dm_validate(),
     "dm_invalid"
   )
@@ -97,7 +97,7 @@ test_that("validator speaks up when something's wrong", {
     dm_for_filter() %>%
       dm_get_def() %>%
       mutate(data = list(1, 2, 3, 4, 5, 6)) %>%
-      new_dm3() %>%
+      dm_from_def() %>%
       dm_validate(),
     "dm_invalid"
   )
@@ -107,7 +107,7 @@ test_that("validator speaks up when something's wrong", {
     dm_for_filter() %>%
       dm_get_def() %>%
       mutate(pks = if_else(table == "tf_1", list_of(new_pk(list("z"))), pks)) %>%
-      new_dm3() %>%
+      dm_from_def() %>%
       dm_validate(),
     "dm_invalid"
   )
@@ -121,7 +121,7 @@ test_that("validator speaks up when something's wrong", {
         list_of(new_fk(ref_column = list("y"), table = "tf_8", column = list("z"), on_delete = "no_action")),
         fks
       )) %>%
-      new_dm3() %>%
+      dm_from_def() %>%
       dm_validate(),
     "dm_invalid"
   )
@@ -131,7 +131,7 @@ test_that("validator speaks up when something's wrong", {
     dm_for_filter() %>%
       dm_get_def() %>%
       mutate(fks = if_else(table == "tf_1", list_of(new_fk(list("a"), "tf_2", list("z"), "no_action")), fks)) %>%
-      new_dm3() %>%
+      dm_from_def() %>%
       dm_validate(),
     "dm_invalid"
   )
@@ -141,7 +141,7 @@ test_that("validator speaks up when something's wrong", {
     dm_for_filter() %>%
       dm_get_def() %>%
       mutate(fks = if_else(table == "tf_1", list_of(new_fk(list("z"), "tf_2", list("d"), "no_action")), fks)) %>%
-      new_dm3() %>%
+      dm_from_def() %>%
       dm_validate(),
     "dm_invalid"
   )
@@ -154,7 +154,7 @@ test_that("validator speaks up when something's wrong", {
       } else {
         .x
       }))) %>%
-      new_dm3() %>%
+      dm_from_def() %>%
       dm_validate(),
     "dm_invalid"
   )
@@ -167,7 +167,7 @@ test_that("validator speaks up when something's wrong", {
       } else {
         .x
       }))) %>%
-      new_dm3() %>%
+      dm_from_def() %>%
       dm_validate(),
     "dm_invalid"
   )
@@ -180,27 +180,24 @@ test_that("validator speaks up when something's wrong", {
       } else {
         .x
       }))) %>%
-      new_dm3() %>%
+      dm_from_def() %>%
       dm_validate(),
     "dm_invalid"
   )
 })
 
 test_that("validator speaks up (sqlite())", {
-  skip_if_not_installed("dbplyr")
-
   expect_dm_error(
     dm_for_filter() %>%
       dm_get_def() %>%
       mutate(data = if_else(table == "tf_1", list(dm_for_filter_duckdb()$tf_1), data)) %>%
-      new_dm3() %>%
+      dm_from_def() %>%
       dm_validate(),
     "dm_invalid"
   )
 })
 
 test_that("validator accepts tbl_sql which is not tbl_dbi (from copy_inline())", {
-  skip_if_not_installed("dbplyr")
   skip_if_src("df")
 
   con <- my_test_con()
